@@ -43,7 +43,7 @@ fi
 
 # Load user's preferences, if any
 if [ -f "$HOME/.foprc" ]; then
-    . $HOME/.foprc
+    . "$HOME/.foprc"
 fi
 
 # We prefer to use openjdk or Sun's java if available
